% Descripcin :  cinicgs.m
%
% Objetivo :
%  Calcular las condiciones iniciales de operacin del generador sncrono
%  del Ge3-13.2 del problema taylor 2 dinmica.

function [delta]=cinicgs(Ug,teta,Pg,Qg,Ra,Xd,Xq,Xdp,K)
%Ug=1.0165; teta=8.8871; Pg=1.094; Qg=0.0165; Xd=1.31875; Xdp=0.175; Xq=1.2625
%Ra=0.002875; K=200;

%Definicin de Parmetros:
%Ug   : Mdulo de la tensin en bornes del generador
%Teta : Fase de la tensin en bornes del generador
%Pg   : Potencia activa generada por el generador
%Qg   : Potencia reactiva generada por el generador
%Ra   : Resistencia del estator del generador
%Xd   : Reactancia de eje directo del generador 
%Xq   : Reactancia de eje en cuadratura del generador
%Xdp  : Reactancia de eje directo prima del generador X'd
%K    : Constante del regulador

Ug=Ug*exp(j*teta*pi/180); 				%Tensin en bornes del generador
Ig=(Pg-j*Qg)/conj(Ug);					%Corriente entregada por el generador
Eq=Ug+(Ra+j*Xq)*Ig;
delta=angle(Eq);

%valores instantneos de las corrientes y tensiones de eje d y q
A=[sin(delta) cos(delta); - cos(delta) sin(delta)];
idq=inv(A)*[real(Ig); imag(Ig)];
udq=inv(A)*[real(Ug); imag(Ug)];

%fasores de las corrientes y tensiones de eje d y q
Id=idq(1)*exp(j*(delta-pi/2));
Iq=idq(2)*exp(j*delta);
Ud=udq(1)*exp(j*(delta-pi/2));
Uq=udq(2)*exp(j*delta);
%Tensin E'q
Eqp =abs( Uq + Ra*Iq + j*Xdp*Id);

%Tensin El
El = abs(Eq + j*(Xd - Xq)*Id);

%Tensin de referencia para el regulador de tensin de la excitacin
Uref=El/K + abs(Ug);




