% Descripcin :  genosc.m
%
% Este bloque S-function actua como una subrutina ejecutada en Matlab.
% no existen variables continuas (derivadas)
% se evalua la salida como:
%  y = f(u)
%  u : entradas
%  y : Salidas   son  devueltas en sys
%
% Objetivo :
%
% Resolver la Ecuacin de oscilacin del Generador sncrono
%

function [sys, x0]=genosc(t,x,u,flag,H,Ug,teta,Pg,Qg,Ra,Xd,Xq,Xdp,K)
% Parmetros :
%  H    : Constante de Inercia
%  Ug   : Modulo de la tensin del nudo
%  teta : Fase de la tensin del nudo
%  Pg   : Potencia activa generada
%  Qg   : Potencia reactiva generada
%  Ra   : Resistencia del estator
%  Xd   : Reactancia de eje d
%  Xq   : Reactancia de eje q
%  Xdp  : Reactancia Xd'
%  K    : Constante del Regulador  
% Variables de estado
%  x(1) = delta
%  x(2) = Incremento de velocidad del rotor Wr
% Variables de entrada:
%  u(1) = i'd
%  u(2) = i'q
%  u(3) = u'd
%  u(4) = u'q

%Ecuacin de Oscilacin del Generador

if abs(flag)==1
   %variables de estado del sistema
   sys(1) = x(2)*2*pi*60;                          %Debe multiplicarse por Wbase
   sys(2) = 1/(2*H)*(Pg - u(1)*u(3) - u(2)*u(4));  %Tmo(pu) = Pg(pu.)
elseif flag==3
      %salida del sistema
      sys=[x(1); x(2)];
   elseif flag==0
         %parametros y condiciones iniciales  
         %1ro: Numero de estados continuos
         %2do: Numero estados discretos
         %3ro: Numero de salidas  X
         %4to: Numero de entradas U
         sys=[2;0;2;4;0;0];
         [delta0]=cinicgs(Ug,teta,Pg,Qg,Ra,Xd,Xq,Xdp,K); %Calculo de delta inicial
         x0=[delta0 ; 0];        
      else
         sys=[];
 end
