% Descripcin:  sisgen.m
%
% Este bloque S-function actua como una subrutina ejecutada en Matlab.
% no existen variables continuas (derivadas)
% se evalua la salida como:
%  y = f(u)
%   u : entradas
%   y : Salidas   son  devueltas en sys
%
% Objetivo :
%  Representar el sistema equivalente al que se conecta el generador sncrono
%
function [sys, x0 ]=sisgen(t,x,u,flag,U1,teta,Rsis,Xsis)

% Parmetros :
%  U1    : Mdulo tensin del primario
%  teta  : ngulo en grados de la tensin del primario
%  Rsis  : Resistencia del sistema equivalente conectado al motor
%  Xsis  : Reactancia del sistema equivalente conectado al motor 
% Variables de Salida
%  sys(1) = ur          : Parte real de la tensin del generador
%  sys(2) = ui          : Parte imaginaria de la tensin del generador
%Variables de entrada:
%  u(1) = ir            : Parte real de la corriente cedida por el generador 
%  u(2) = ii            : Parte imaginaria de la corriente cedida por el generador 
if flag==3
   %salida del sistema
   U1=U1/1.06*exp(j*teta*pi/180);      %Tensin del equivalente del sistema 
   Ug=U1+(Rsis + j*Xsis)*(u(1)+j*u(2));
   sys(1)=real(Ug);
   sys(2)=imag(Ug);
   
  elseif flag==0
         %parametros y condiciones iniciales
         %1ro: Numero de estados continuos
         %2do: Numero estados discretos
         %3ro: Numero de salidas  X
         %4to: Numero de entradas U
         % los otros cero
         sys=[0;0;2;2;0;1];
         x0=[];        
      else
         sys=[];
 end
