% Descripcin :  sismo.m
%
% Este bloque S-function actua como una subrutina ejecutada en Matlab.
% no existen variables continuas (derivadas)
% se evalua la salida como:
% y = f(u)
%  u : entradas
%  y : Salidas   son  devueltas en sys
%
% Objetivo :
%  Representar el sistema equivalente conectado al motor de induccin

function [sys, x0 ]=sismo(t,x,u,flag,U1,gU1,Rsis,Xsis,Rs,Xs,Xm,Xr)

% Parmetros :
%  U1    : Mdulo tensin del primario
%  gU1   : ngulo en grados de la tensin del primario
%  Rsis  : Resistencia del sistema equivalente conectado al motor
%  Xsis  : Reactancia del sistema equivalente conectado al motor 
%  Rs    : Resistencia del estator del motor
%  Xs    : Reactancia del estator del motor
%  Xm    : Reactancia de magnetizacin
%  Xr    : Reactancia del rotor
% Variables de Salida
%  sys(1) = imd     : Parte real de la intensidad del motor
%  sys(2) = imq     : Parte imaginaria de la intensidad del motor
% Variables de entrada:
%  u(1) = upd       : Parte real de la tensin del rotor del motor 
%  u(2) = upq       : Parte imaginaria de la tensin del rotor del motor 

if flag==3
   %salida del sistema
   %Tensin del equivalente del sistema conectado al trafo (para este caso particular)
   U1=U1*0.97610551056340*exp(j*gU1*pi/180);

   Zeq=Rsis+j*Xsis+Rs+j*(Xs+Xm*Xr/(Xm+Xr));
   Im=(U1-(u(1)+j*u(2)))/Zeq;
   sys(1)=real(Im);
   sys(2)=imag(Im);
   
  elseif flag==0
         %parametros y condiciones iniciales
         %1ro: Numero de estados continuos
         %2do: Numero estados discretos
         %3ro: Numero de salidas  X
         %4to: Numero de entradas U
         % los otros cero
         sys=[0;0;2;2;0;1];
         x0=[];        
      else
         sys=[];
 end
