% Descripcin:  sistrafo.m
%
% Este bloque S-function actua como una subrutina ejecutada en Matlab.
% no existen variables continuas (derivadas)
% se evalua la salida como:
%  y = f(u)
%  u : entradas
%  y : Salidas   son  devueltas en sys
%
% Objetivo :
%
%  Representar sistema elctrico equivalente conectado a la carga termosttica y LTC

function [sys, x0 ]=sistrafo(t,x,u,flag,U1,gU1,Rtrafo,Xtrafo,Rc,Xc,Kld,P2t,Q2t,Kg,Rload,Rsis,Xsis)

% Parmetros :
%  U1 : Mdulo tensin del primario
%  gU1: ngulo en grados de la tensin del primario
%  Rtrafo,Xtrafo : Parmetros trafo
%  Rc, Xc: Compensacin line drop  (va en serie con sec. trafo)
%  Kld : Factor de compensacin line drop
%  P2t, Q2t : Carga en sec. trafo.
%  Kg : Variable auxiliar que toma los siguientes valores:
%      Kg = 1      Modelo con carga termosttica
%      Kg = 0      Modelo sin carga termosttica
%  Rload : Resistencia de carga independiente de la tensin
%  Rsis  : Resistencia del sistema equivalente conectado al trafo
%  Xsis  : Reactancia del sistema equivalente conectado al trafo 
% Variables de Salida
%  sys(1) = u2m    : Tensin en punto de compensacin line drop
%  sys(2) = u2     : Tensin en la carga
% Variables de entrada:
%  u(1) = Relacin de transformacin 
%  u(2) = G termosttica (variable en el tiempo con el cuadrado de la tensin)

if flag==3
   %salida del sistema
   U1=U1*0.95523*exp(j*gU1*pi/180); %Tensin del equivalente del sistema 
   Rtrafo=Rtrafo+Rsis/u(1)^2;
   Xt=Xtrafo+Xsis/u(1)^2;   
   if Rload==0
      Gload=0;
   else
      Gload=1/Rload;
   end
   if Kg==0   
      G=Gload;
   else
      G=u(2)+Gload;
   end
   A=1 + 2*Rtrafo*G + (Rtrafo^2 + Xt^2)*G^2;
   B=2*Rtrafo*P2t + 2*Xt*Q2t + (Rtrafo^2 + Xt^2)*2*P2t*G  - (abs(U1)/u(1))^2;
   C=(P2t^2 + Q2t^2)*(Rtrafo^2 + Xt^2);
   u2=max(roots([A B C]));           %Cuadrado de la tension en la carga u2
   Pt=P2t+G*u2;
   Qt=Q2t;
   St=Pt+j*Qt;
   teta2=gU1*pi/180 - asin( (Xt*Pt-Rtrafo*Qt) / ( abs(U1)/u(1)*sqrt(u2) ) );
   u2t=sqrt(u2)*exp(j*teta2);
   I2=conj(St/u2t);
   U2m=U1/u(1) - I2*(Rtrafo+Kld*Rc+j*(Xt+Kld*Xc));
   sys(1)=abs(U2m);
   sys(2)=sqrt(u2);
   %sys(2)=abs(U2m+Kld*(Rc+j*Xc));
   %pause
   %sys(2)=7;
   elseif flag==0
         %parametros y condiciones iniciales
         %1ro: Numero de estados continuos
         %2do: Numero estados discretos
         %3ro: Numero de salidas  X
         %4to: Numero de entradas U
         % los otros cero
         sys=[0;0;2;2;0;1];
         x0=[];        
      else
         sys=[];
 end
